@@ -1,3 +1,6 @@
+__all__ = ("MDRenderer", "MARKERS", "LOGGER")
+
+
 import logging
 from typing import Any, Mapping, Optional, Sequence
 
@@ -7,8 +10,6 @@ from markdown_it.token import Token
 from mdformat.renderer import _container_renderers, _token_renderers
 from mdformat.renderer._util import MARKERS, removesuffix
 
-__all__ = ("MDRenderer", "MARKERS", "LOGGER")
-
 LOGGER = logging.getLogger(__name__)
 
 
@@ -75,6 +76,9 @@ class MDRenderer:
                 continue
 
             if token.type == "inline":
+                assert (
+                    token.children is not None
+                ), "inline token children can not be None"
                 # inline tokens require nested rendering
                 result = self.render(
                     token.children,
@@ -136,7 +140,6 @@ class MDRenderer:
             item = f"[{label.lower()}]: {destination}"
             title = ref["title"]
             if title:
-                title = unescape_string(title)
                 title = title.replace('"', '\\"')
                 item += f' "{title}"'
             text += item + "\n"
